<?php
/**
 * Yii extension implementing EasyFramework - client side framework (css and js)
 *
 * This class will put on layout the required javascripts and stylesheets to EasyFramework work.
 * 
 * ATENTION: - Remove from your layout all Yii default javascript and stylesheet(blueprint framework)
 *           - Only leave the main.css and form.css
 *           - Add the 'easyframework' to 'preload' on 'config/main.php'
 * 
 * @author Paulo Coutinho
 * @version 1.0
 * @filesource EEasyFramework.php
 * @link http://www.prsolucoes.com
 *
 */
 class EEasyFramework extends CApplicationComponent
{
    private $baseUrl;
    private $clientScript;
    
    private $randomID;
    
    /**
     * This propertie will make or no the file cache on client browser
     */
    public $cache = true;
    
    /**
     * Init the extension
     */
    public function init()
    {
        $this->randomID = date('YdmHis');
        
        $this->publishAssets();
        $this->registerClientScripts();
        
        parent::init();
    }
    
    /**
    * Publishes the assets
    */
    public function publishAssets()
    {
        $dir = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'assets';
        $this->baseUrl = Yii::app()->getAssetManager()->publish($dir);
    }
    
    /**
    * Registers the external javascript files
    */
    public function registerClientScripts()
    {
        // add the scripts
        if ($this->baseUrl === '')
            throw new CException(Yii::t('EEasyFramework', 'baseUrl must be set. This is done automatically by calling publishAssets()'));

        $this->clientScript = Yii::app()->getClientScript();
        $this->clientScript->registerCoreScript('jquery');
        $this->clientScript->registerScriptFile($this->baseUrl.'/js/easy.js' . ($this->cache == true ? '' : '?rnd=' . $this->randomID));
        $this->clientScript->registerScriptFile($this->baseUrl.'/js/main.js' . ($this->cache == true ? '' : '?rnd=' . $this->randomID));
        
        // add the stylesheets
        $this->clientScript->registerCssFile($this->baseUrl.'/css/easyprint.css' . ($this->cache == true ? '' : '?rnd=' . $this->randomID), 'print');
        $this->clientScript->registerCssFile($this->baseUrl.'/css/easy.css' . ($this->cache == true ? '' : '?rnd=' . $this->randomID));        
    }
}